@@ -113,7 +113,7 @@ LZMA_decompress(__attribute__((unused)) PyObject *self, PyObject *args, PyObject
 
 	static char *kwlist[] = {"input", "bufsize", "memlimit", NULL};
 
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#|ll:decompress", kwlist,
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#|lK:decompress", kwlist,
 			  &input, &length, &r_strlen, &memlimit))
 		return NULL;
 
@@ -196,7 +196,7 @@ LZMA_crc64(__attribute__((unused)) PyObject *self, PyObject *args)
 	uint64_t crc64val = lzma_crc64(NULL, (size_t)0, (uint64_t)0);
     	uint8_t *buf;
     	Py_ssize_t size;
-    	if (!PyArg_ParseTuple(args, "s#|k:crc64", &buf, &size, &crc64val))
+    	if (!PyArg_ParseTuple(args, "s#|K:crc64", &buf, &size, &crc64val))
 		return NULL;
     	crc64val = lzma_crc64(buf, (size_t)size, crc64val);
     	return PyLong_FromUnsignedLongLong(crc64val);
