@@ -9,14 +9,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #if defined (__APPLE__) || defined(__FreeBSD__) || \
-    defined(__OpenBSD__) || defined(__NetBSD__)
+    defined(__OpenBSD__) || defined(__NetBSD__) || \
+    defined (__sun) || defined (__svr4__)
 #include <stdlib.h>
 #else
 #include <malloc.h>
 #endif
 #include <string.h>
 #include <inttypes.h>
-#ifndef linux
+#if !defined(linux) && !defined(__sun) && !defined(__svr4__)
 typedef unsigned long ulong;
 #endif
 #include <sys/types.h>
@@ -35,6 +36,8 @@ typedef unsigned long ulong;
 #if __STDC_VERSION__ >= 199901L
 #include <stdbool.h>
 #endif
+#elif defined(__C99FEATURES__)
+#include <stdbool.h>
 #else
 #define bool    uint8_t
 #define true    1
@@ -44,6 +47,15 @@ typedef unsigned long ulong;
 #endif
 #endif
 
+#if PY_VERSION_HEX < 0x02060000
+#if defined(MS_WINDOWS) || defined(PYOS_OS2)
+#define PyOS_stricmp stricmp
+#else
+#define PyOS_stricmp strcasecmp
+#endif
+#endif
+
 #define INITCHECK if (!self->is_initialised) {	PyErr_Format(PyExc_RuntimeError, "%s object not initialised!", self->ob_type->tp_name);	return NULL; }
 
+PyObject *module;
 #endif /* LIBLZMA_H */
