@@ -2,7 +2,7 @@
 #include "liblzma_util.h"
 
 PyDoc_STRVAR(LZMADecomp_decompress__doc__,
-"decompress(data[, max_length=0, memlimit=-1]) -> string\n\
+"decompress(data[, max_length=0]) -> string\n\
 \n\
 Return a string containing the decompressed version of the data.\n\
 \n\
@@ -22,11 +22,11 @@ LZMADecomp_decompress(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
 	PyObject *RetVal = NULL;
 	lzma_stream *lzus = &self->lzus;
 	lzma_ret lzuerror;
-	static char *kwlist[] = {"input", "max_length", "memlimit", NULL};
+	static char *kwlist[] = {"input", "max_length", NULL};
    
 	INITCHECK
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#|ll:decompress", kwlist,
-			  &input, &inplen, &self->max_length, &self->memlimit))
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#|l:decompress", kwlist,
+			  &input, &inplen, &self->max_length))
 		return NULL;
 
 	ACQUIRE_LOCK(self);
@@ -174,8 +174,6 @@ static PyObject * LZMADecomp_flush(LZMADecompObject *self, PyObject *args, PyObj
 	if (!(RetVal = PyString_FromStringAndSize(NULL, length)))
 		goto error;
 
-	lzma_stream tmp = LZMA_STREAM_INIT;
-	*lzus = tmp;
 
 	start_total_out = lzus->total_out;
 	lzus->avail_out = (size_t)length;
@@ -235,7 +233,7 @@ LZMADecomp_reset(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
     	static char *kwlist[] = {"max_length", "memlimit", NULL};
 
 	INITCHECK
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|ll:reset", kwlist,
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|lK:reset", kwlist,
 				&self->max_length, &self->memlimit))
 		return NULL;
 
@@ -247,6 +245,7 @@ LZMADecomp_reset(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
 	ACQUIRE_LOCK(self);	
 	if (self->running)
 		lzma_end(lzus);
+	
 	Py_CLEAR(self->unused_data);
 	Py_CLEAR(self->unconsumed_tail);
 	if((self->unused_data = PyString_FromString("")) == NULL)
@@ -254,6 +253,9 @@ LZMADecomp_reset(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
 	if((self->unconsumed_tail = PyString_FromString("")) == NULL)
 		goto error;
 
+	lzma_stream tmp = LZMA_STREAM_INIT;                      
+ 	*lzus = tmp;                                             
+
 	lzuerror = lzma_auto_decoder(lzus, self->memlimit, 0);
 	if(!Util_CatchLZMAError(lzuerror, lzus, false))
 		goto error;
@@ -334,7 +336,7 @@ LZMADecomp_init(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
 
 	static char *kwlist[] = {"input", "max_length", "memlimit", NULL};
 
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|ll:LZMADecompressor", kwlist,
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|lK:LZMADecompressor", kwlist,
 				&self->max_length, &self->memlimit))
 		return -1;
 
@@ -352,7 +354,7 @@ LZMADecomp_init(LZMADecompObject *self, PyObject *args, PyObject *kwargs)
 		goto error;
 	}
 
-	lzuerror = lzma_auto_decoder(lzus, self->memlimit, 0);
+	lzuerror = lzma_auto_decoder(lzus, self->memlimit, LZMA_CONCATENATED);
 	if(!Util_CatchLZMAError(lzuerror, lzus, false))
 		goto error;
 
