@@ -579,7 +579,6 @@ LZMAFile_seek(LZMAFileObject *self, PyObject *args)
 	} else {
 		/* we cannot move back, so rewind the stream */
 		lzma_close_real(&lzuerror, self->fp);
-		lzma_open_real(&lzuerror, self->filters, PyFile_AsFile(self->file), self->memlimit);
 		if (lzuerror != LZMA_OK) {
 			Util_CatchLZMAError(lzuerror, &self->fp->strm, self->fp->encoding);
 			goto cleanup;
@@ -804,7 +803,7 @@ LZMAFile_init(LZMAFileObject *self, PyObject *args, PyObject *kwargs)
 	self->size = -1;
 	self->memlimit = -1;
 
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O|silO:LZMAFile", kwlist,
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O|siKO:LZMAFile", kwlist,
 					&name, &mode, &buffering, &self->memlimit, &options_dict))
 		return -1;
 
