@@ -35,6 +35,8 @@ typedef struct {
 
 	lzma_FILE *fp;
 	lzma_options_lzma options;
+	lzma_filter filters[LZMA_FILTERS_MAX + 2];
+	uint64_t memlimit;
 
 	bool open;
 	Py_off_t pos;
